::: maggma.stores.mongolike

::: maggma.stores.file_store

::: maggma.stores.gridfs

::: maggma.stores.aws

::: maggma.stores.advanced_stores

::: maggma.stores.compound_stores

::: maggma.stores.ssh_tunnel
